==> zio-aws-chimesdkmediapipelines_2.13-6.20.42.1-sources.jar: zio/aws/chimesdkmediapipelines/model/UntagResourceRequest.scala <==
package zio.aws.chimesdkmediapipelines.model
import zio.ZIO
import zio.aws.chimesdkmediapipelines.model.primitives.{
  TagKey,
  AmazonResourceName
}
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class UntagResourceRequest(
    resourceARN: AmazonResourceName,
    tagKeys: Iterable[TagKey]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmediapipelines.model.UntagResourceRequest = {
    import UntagResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmediapipelines.model.UntagResourceRequest
      .builder()
      .resourceARN(AmazonResourceName.unwrap(resourceARN): java.lang.String)
      .tagKeys(tagKeys.map { item =>
        TagKey.unwrap(item): java.lang.String
      }.asJavaCollection)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmediapipelines.model.UntagResourceRequest.ReadOnly =
    zio.aws.chimesdkmediapipelines.model.UntagResourceRequest
      .wrap(buildAwsValue())
}
object UntagResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmediapipelines.model.UntagResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.chimesdkmediapipelines.model.UntagResourceRequest =
      zio.aws.chimesdkmediapipelines.model
        .UntagResourceRequest(resourceARN, tagKeys)
    def resourceARN: AmazonResourceName
    def tagKeys: List[TagKey]
    def getResourceARN: ZIO[Any, Nothing, AmazonResourceName] =
      ZIO.succeed(resourceARN)
    def getTagKeys: ZIO[Any, Nothing, List[TagKey]] = ZIO.succeed(tagKeys)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.UntagResourceRequest
  ) extends zio.aws.chimesdkmediapipelines.model.UntagResourceRequest.ReadOnly {
    override val resourceARN: AmazonResourceName =
      zio.aws.chimesdkmediapipelines.model.primitives
        .AmazonResourceName(impl.resourceARN())
    override val tagKeys: List[TagKey] = impl
      .tagKeys()
      .asScala
      .map { item =>
        zio.aws.chimesdkmediapipelines.model.primitives.TagKey(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.UntagResourceRequest
  ): zio.aws.chimesdkmediapipelines.model.UntagResourceRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-chimesdkmediapipelines_3-5.19.7.4-sources.jar: zio/aws/chimesdkmediapipelines/model/UntagResourceRequest.scala <==
package zio.aws.chimesdkmediapipelines.model
import zio.ZIO
import zio.aws.chimesdkmediapipelines.model.primitives.{
  TagKey,
  AmazonResourceName
}
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class UntagResourceRequest(
    resourceARN: AmazonResourceName,
    tagKeys: Iterable[TagKey]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmediapipelines.model.UntagResourceRequest = {
    import UntagResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmediapipelines.model.UntagResourceRequest
      .builder()
      .resourceARN(AmazonResourceName.unwrap(resourceARN): java.lang.String)
      .tagKeys(tagKeys.map { item =>
        TagKey.unwrap(item): java.lang.String
      }.asJavaCollection)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmediapipelines.model.UntagResourceRequest.ReadOnly =
    zio.aws.chimesdkmediapipelines.model.UntagResourceRequest
      .wrap(buildAwsValue())
}
object UntagResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmediapipelines.model.UntagResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.chimesdkmediapipelines.model.UntagResourceRequest =
      zio.aws.chimesdkmediapipelines.model
        .UntagResourceRequest(resourceARN, tagKeys)
    def resourceARN: AmazonResourceName
    def tagKeys: List[TagKey]
    def getResourceARN: ZIO[Any, Nothing, AmazonResourceName] =
      ZIO.succeed(resourceARN)
    def getTagKeys: ZIO[Any, Nothing, List[TagKey]] = ZIO.succeed(tagKeys)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.UntagResourceRequest
  ) extends zio.aws.chimesdkmediapipelines.model.UntagResourceRequest.ReadOnly {
    override val resourceARN: AmazonResourceName =
      zio.aws.chimesdkmediapipelines.model.primitives
        .AmazonResourceName(impl.resourceARN())
    override val tagKeys: List[TagKey] = impl
      .tagKeys()
      .asScala
      .map { item =>
        zio.aws.chimesdkmediapipelines.model.primitives.TagKey(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.UntagResourceRequest
  ): zio.aws.chimesdkmediapipelines.model.UntagResourceRequest.ReadOnly =
    new Wrapper(impl)
}
